Class: Aws::ElasticLoadBalancing::Waiters::InstanceInService
- Inherits:
-
Object
- Object
- Aws::ElasticLoadBalancing::Waiters::InstanceInService
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-elasticloadbalancing/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ InstanceInService
constructor
A new instance of InstanceInService.
-
#wait(params = {}) ⇒ Types::DescribeEndPointStateOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ InstanceInService
Returns a new instance of InstanceInService.
165 166 |
# File 'lib/aws-sdk-elasticloadbalancing/waiters.rb', line 165
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
196 197 198 |
# File 'lib/aws-sdk-elasticloadbalancing/waiters.rb', line 196 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeEndPointStateOutput
Returns a response object which responds to the following methods:
- #instance_states => Array<Types::InstanceState>
191 |
# File 'lib/aws-sdk-elasticloadbalancing/waiters.rb', line 191
def wait: (
|